@@ -5,7 +5,7 @@ use Carp;
 use Tie::File;
 use Fcntl qw(:Fcompat :DEFAULT :flock); 
 use vars qw($VERSION);
-$VERSION = 0.64;
+$VERSION = 0.65;
 
 our $file_passwd = '/etc/passwd';
 our $file_shadow = '/etc/shadow';
@@ -169,13 +169,13 @@ sub add {
 			$fields{password} = _gen_pass($_) if $_;
 		}
 		if($c == 3){
-			$_ == '' and $_ = 1000;
+			$_ eq '' and $_ = 1000;
 		 	croak "wrong uid" unless /^\d+$/;
 			croak "wrong uid" if $_ > 65535 or $_ < 1;
 			$fields{uid} = $_ || 1000;
 		}
 		if($c == 4){
-			$_ == '' and $_ = 1000;
+			$_ eq '' and $_ = 1000;
 			croak "wrong gid" unless /^\d+$/;
 			if(/^\d+$/){ croak "wrong gid" if $_ > 65535 or $_ < 1 }
 			$fields{gid} = $_ || $fields{uid};
@@ -230,6 +230,7 @@ sub del{
 	@old = _io_file("$file_shadow", '', 'r');
 	/^(.[^:]*):/ and $1 eq $username or push @new, $_ for @old;
 	_io_file("$file_shadow", \@new, 'w');
+	return 1
 }
 
 sub tobsd{
@@ -253,6 +254,7 @@ sub tobsd{
 		s/.*/$user/;
 	}
 	_io_file("$file_shadow", \@file, 'w');
+	return 1
 }
 
 sub _io_file{
@@ -263,20 +265,23 @@ sub _io_file{
 	croak $! unless -f $file;
 	croak "posible flags: r/w/a" unless $flag =~ /^(r|w|a)$/;
 	if($flag eq 'r'){
-		tie @file, 'Tie::File', $file, mode => O_RDONLY | LOCK_EX;
+		tie @file, 'Tie::File', $file, mode => O_RDONLY | LOCK_EX 
+			or croak "can't open_r $file";
 		@retval = @file;
 		untie @file;
 		return @retval
 	}
 	if($flag eq 'w'){
-		tie @file, 'Tie::File', $file, mode => O_RDWR | LOCK_EX;
+		tie @file, 'Tie::File', $file, mode => O_RDWR | LOCK_EX
+			or croak "can't open_w $file";
 		@file = ();
 		push @file, "$_\n" for @{$newvals};
 		untie @file;
 		return 1
 	}
 	if($flag eq 'a'){
-		tie @file, 'Tie::File', $file, mode => O_RDWR | LOCK_EX;
+		tie @file, 'Tie::File', $file, mode => O_RDWR | LOCK_EX
+			or croak "can't open_a $file";
 		push @file, "$_\n" for @{$newvals};
 		untie @file;
 		return 1
@@ -327,56 +332,55 @@ Linux::usermod - modify user accounts
 
 =head1 SYNOPSIS
 
-use Linux::usermod;
+  use Linux::usermod;
+  
+  $user = Linux::usermod->new(username);
+  
+  $user->get(gid); # equal to $user->get(3);
+  $user->get(uid); # equal to $user->get(2);
 
-$user = Linux::usermod->new(username);
+  #lock and unlock user account
 
-$user->get(gid); is equal to $user->get(3);
+  $user->lock();
+  $user->unlock();
 
-$user->get(uid); is equal to $user->get(2);
+  #get password(passwd file)
+  $user->get(ppassword);
 
-lock and unlock user account
+  #get encoded password(shadow file)
+  $user->get(password); 
 
-$user->lock();
-$user->unlock();
+  #set encoded password
+  $user->set(password); 
 
-get password(passwd file)
+  #set shell
+  $user->set(shell);
 
-$user->get(ppassword);
+  Linux::usermod->add(username);
 
-get encoded password(shadow file)
+  #or
 
-$user->get(password); 
+  Linux::usermod->add(username, password, uid, gid, comment, home, shell);
 
-set encoded password
-$user->set(password); 
+  #where the password goes in shadow file and gid becomes 
+  #equal to uid unless specified and uid is becoming the 
+  #first unreserved number after 1000 unless specified
 
-$user->set(shell);
+  #delete user
+  Linux::usermod->del(username);
 
-Linux::usermod->add(username);
+  #all fields are returned from the class method fields
+  print $user->get($_) for (Linux::usermod->fields);
 
-or
+  #set working passwd and shadow files
 
-Linux::usermod->add(username, password, uid, gid, comment, home, shell);
-
-where the password goes in shadow file and gid becomes 
-equal to uid unless specified and uid is becoming the 
-first unreserved number after 1000 unless specified
-
-Linux::usermod->del(username);
-
-all fields are returned from the class method fields
-print $user->get($_) for (Linux::usermod->fields);
-
-change passwd and shadow files
-
-$Linux::usermod::file_passwd = "./my_passwd";
-$Linux::usermod::file_shadow = "./my_shadow";
+  #$Linux::usermod::file_passwd = "./my_passwd";
+  #$Linux::usermod::file_shadow = "./my_shadow";
 
 
 =head1 DESCRIPTION
 
-B<Linux::usermod> which adds, removes and modify user account according to 
+B<Linux::usermod> adds, removes and modify user account according to 
 the passwd and shadow files syntax (like struct passwd from pwd.h). It is not necessary 
 those accounts to be system as long as Linux::usermod::file_passwd and Linux::usermod::file_shadow 
 are not in "/etc" directory.
@@ -388,24 +392,18 @@ are not in "/etc" directory.
 =item B<new> 
 	(username)
 
-
 =item B<add> 
 	(username, ...)
 
-
 Class method - add new user account
 arguments to add are optional, except username;
 they may be (username, password, uid, gid, comment, home, shell)
 
 =item B<del> 
 	(username)
-
-
 Class method - removes user account
 
-
 =item B<tobsd> 
-
 converts user fields in shadow / master.passwd file to bsd style
 
 =item B<get> 
@@ -486,7 +484,7 @@ Unlock user account (removes '!' from the beginning of the encoded password)
 
 =item B<users>
 
-Class method - return hash which keys are all users, teken from $file_passwd
+Class method - return hash which keys are all users, taken from $file_passwd
 
 =back
 
